// java wrapper for vtkPointDataToCellData object
//

package vtk;
import vtk.*;

public class vtkPointDataToCellData extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPassPointData_2(int id0);
  public void SetPassPointData(int id0)
    { SetPassPointData_2(id0); }

  private native int GetPassPointData_3();
  public int GetPassPointData()
    { return GetPassPointData_3(); }

  private native void PassPointDataOn_4();
  public void PassPointDataOn()
    { PassPointDataOn_4(); }

  private native void PassPointDataOff_5();
  public void PassPointDataOff()
    { PassPointDataOff_5(); }

  private native void SetCategoricalData_6(int id0);
  public void SetCategoricalData(int id0)
    { SetCategoricalData_6(id0); }

  private native int GetCategoricalData_7();
  public int GetCategoricalData()
    { return GetCategoricalData_7(); }

  private native void CategoricalDataOn_8();
  public void CategoricalDataOn()
    { CategoricalDataOn_8(); }

  private native void CategoricalDataOff_9();
  public void CategoricalDataOff()
    { CategoricalDataOff_9(); }

  public vtkPointDataToCellData() { super(); }

  public vtkPointDataToCellData(long id) { super(id); }
  public native long   VTKInit();

}
